import { Injectable } from '@angular/core';
import { Observable, of, throwError } from 'rxjs';
import { catchError, map, mergeMap, tap } from 'rxjs/operators';
import { HttpClient, HttpHeaders, HttpResponseBase, HttpResponse } from '@angular/common/http';

@Injectable({
  providedIn: 'root'
})
export class StudentService {

  private baseUrl: string;

  constructor(private http: HttpClient) {
    this.http = http;
    this.baseUrl = "http://localhost:54225";
  }

  getPagedList(queryInput: PagedInput): Observable<PagedStudentsOutput> {
    let url = this.baseUrl + "/api/values?page="+queryInput.page+"&pagesize="+queryInput.pageSize;

    let options_ = {
      headers : new HttpHeaders({
        "Content-Type": "application/json",
        "Accept": "application/json",
        "Authorization": "Bearer " +  this.getCookie("auth_token")
    })
    };

    return this.http.get<PagedStudentsOutput>(url, options_).pipe(
      tap(item => console.log("get paged students")),
      catchError(this.handleError<PagedStudentsOutput>("get students"))
    );
  }

  private getCookie(name) {
    var arr, reg = new RegExp("(^| )" + name + "=([^;]*)(;|$)"); //正则匹配
    if (arr = document.cookie.match(reg)) {
        return unescape(arr[2]);
    }
    else {
        return null;
    }
  }

  protected handleError<T>(operation = 'operation', result?: T) {
    return (error: any): Observable<T> => {

        // TODO: send the error to remote logging infrastructure
        console.error(error); // log to console instead

        // Let the app keep running by returning an empty result.
        return of(result as T);
    };
}
}

export class PagedStudentsOutput{
  total:number;
  data:Student[];
}

export class Student {
  id: number;
  name: string;
  age: number;
  sex: string;
}

export class PagedInput {
  page: number;
  pageSize: number;

  constructor() {
      this.page = 1;
      this.pageSize = 10;
  }
}
